@@ -1,9 +1,9 @@
 package Music::Duration;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Add 32nd, 64th, fractional and tuple durations to MIDI-Perl
+# ABSTRACT: Add 32nd, 64th and tuple durations to MIDI-Perl
 
-our $VERSION = '0.0505';
+our $VERSION = '0.0600';
 use strict;
 use warnings;
 
@@ -37,18 +37,6 @@ use MIDI::Simple;
 }
 
 
-sub fractional {
-    my ( $name, $factor ) = @_;
-
-    my $divisor = 1;
-
-    for my $d (qw( w h q e s y x )) {
-        $MIDI::Simple::Length{ $name . $d . 'n' } = $factor / $divisor;
-        $divisor *= 2;
-    }
-}
-
-
 sub tuple {
     my ( $duration, $name, $factor ) = @_;
     $MIDI::Simple::Length{ $name . $duration } = $MIDI::Simple::Length{$duration} / $factor
@@ -64,11 +52,11 @@ __END__
 
 =head1 NAME
 
-Music::Duration - Add 32nd, 64th, fractional and tuple durations to MIDI-Perl
+Music::Duration - Add 32nd, 64th and tuple durations to MIDI-Perl
 
 =head1 VERSION
 
-version 0.0505
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -82,9 +70,6 @@ version 0.0505
 
   # Create and set up a new_score...
 
-  Music::Duration::fractional('z', 5);
-  n('zsn', 'n38') for 1 .. 4; # 4 sixteenth snares in bars of 5 notes
-
   Music::Duration::tuple( 'qn', 'z', 5 );
   n('zqn', 'n38') for 1 .. 5; # 5 snares in place of a standard quarter note
 
@@ -96,27 +81,7 @@ L<MIDI::Simple>.  These are 32nd: yn, dyn, ddyn, tyn and 64th: xn, dxn, ddxn, tx
 Also, this module allows the addition of non-standard note divisions with the
 B<fractional()> and B<tuple()> functions, detailed below.
 
-=head1 FUNCTIONS
-
-=head2 fractional()
-
-  Music::Duration::fractional( 'z', 5 )
-  # Then: $score->n( 'zqn', ... );
-
-Add a fractional division to the L<MIDI::Simple> C<Length> hash.
-
-For the given example of C<z5>, this function adds the following durations:
-
-  zwn = 5
-  zhn = 2.5
-  zqn = 1.25
-  zen = 0.625
-  zsn = 0.3125
-  zyn = 0.15625
-  zxn = 0.078125
-
-This means that a whole note is 5 beats long, and the duration for each
-subsequent division is "half as long as the last."
+=head1 FUNCTION
 
 =head2 tuple()
 
@@ -131,10 +96,6 @@ Musically, this creates a "cluster" of notes in place of the given B<duration>.
 So instead of a whole note of four beats, we instead play 5 beats.  A triplet is
 a 3-tuple.
 
-=head1 TO DO
-
-Add dot, double-dot and triplet to the fractional durations.
-
 =head1 SEE ALSO
 
 The "Parameters for n/r/noop" section in L<MIDI::Simple>
